@@ -49,13 +49,12 @@ class TaskScheduler(object):
         self.redis_port = redis_port
         self.username = redis_username
         self.password = redis_password
-        self.jobs_key = self.project_name + ':apscheduler:jobs:' + str(uuid_number).strip() + str(os.getpid())
-        self.run_times_key = self.project_name + ':apscheduler:run_times:' + str(uuid_number).strip() + str(os.getpid())
+        self.jobs_key = self.project_name + ':apscheduler:jobs:' + uuid_number + ":" + str(os.getpid())
+        self.run_times_key = self.project_name + ':apscheduler:run_times:' + uuid_number + ":" + str(os.getpid())
         self.thread_pool_size = thread_pool_size
         self.job_coalesce = job_coalesce
         self.job_max_instance = job_max_instance
         self.job_misfire_grace_time = job_misfire_grace_time
-
         self.redis = Redis(
             host=self.redis_host,
             port=self.redis_port,
